/**
 * Detect Spreed WebRTC, listen to messages from spreed
 * for screensharing and take the corresponding actions.
 */
(function(body) {
	/* Detect if we are in the spreed iframe, otherwise return */
	if (!document.getElementById("globalcontext")) {
		return;
	}
	if (!body.hasAttribute("spreed-webrtc") &&
		body.getAttribute("ng-controller") !== "MediastreamController") {
		return;
	}
	console.log("Spreed WebRTC detected. Listening for messages...");
	/* Init nw's Screen API */
	nw.Screen.Init();

	/* Listen for dom message events from spreed. */
	window.addEventListener("message", function(event) {
		if (event.source !== window) {
			return;
		}

		var msg = event.data;
		if (msg.answer || msg.Type !== "Call") {
			return;
		}

		var call = msg.Call;
		if (call.Type !== "Action") {
			return;
		}

		/* Mark to avoid loops. */
		msg.answer = true;

		switch(call.Action) {
			case "chooseDesktopMedia":
				nw.Screen.chooseDesktopMedia(["screen", "window"], function(id) {
					if (chrome.runtime.lastError) {
						msg.Call = {
								Type: "Error",
								Error: chrome.runtime.lastError.message || chrome.runtime.lastError
						};
					} else {
						msg.Call = {
								Type: "Result",
								Result: id
						};
					}
					window.postMessage(msg, window.document.URL);
				});
				break;
			case "cancelChooseDesktopMedia":
				chrome.desktopCapture.cancelChooseDesktopMedia(call.Args);
				break;
			default:
				console.log("Unknown call action: ", call.Action);
				break;
		}
	});

	/*
	 * Webmeetings detects if the screensharing extension
	 * is available by checking for the presence of this
	 * marker element. If it is not available webmeetings
	 * shows a dialog that the extension needs to be installed.
	 */
	var marker = document.createElement("div");
	marker.id = "chromeextension-available";
	marker.className = "hidden";
	document.body.appendChild(marker);

}(document.body));